@@ -58,7 +58,7 @@ class Local(Target):
         assert isdir(src)
         if not src.endswith('/'): src+='/'
         assert dst
-        self.Dir(dst).set()
+        self.dir(dst).set()
         info(f'\tsync {src} -> {dst}')
         return self.rsync(f'{src} {dst}')
 
